<?php

/**
 * komunikacja actions.
 *
 * @package    sam3
 * @subpackage komunikacja
 * @author     Maciej Kamiński
 * 
 * @desc:: Modul sluzy do zarzadzania informacja komunikacji miejskiej. Modul
 * obsluguje import z systemow AGC Busman oraz Municom++. Obydwa importy sa
 * realizowane poprzez analize struktury katalogow oraz zawartosci plikow html
 * wygenerowanych przez natywne aplikacje Busman i Municom++.
 *
 * Ze wzgledu na brak ujednoliconej struktury danych zawartych w plikach html
 * metody importu na potrzeby kazdego nowego wdrozenia powinny byc dostosowane
 * indywidualnie.
 *
 * Ponadto dla kazdego wdrozenia prosze ustawic domyslne lokalizacje GPS 
 * (actx, acty, actz) dla mechanizmow googlemaps (web/js/komunikacja/)
 * 
 * Import poszukuje struktury plikow w katalogach:
 * -web/uploads/rozklady - dla importu Busman
 * -web/uploads/rozklady-municom - dla importu Municom++
 *
 * Prosze zwrocic szczegolna uwage na prawa dostepu do tych katalogow (dostep
 * odczytu dla uzytkownika na jakim pracuje serwer Apache
 *
 * Modul do prawidlowej pracy potrzebuje nastepujacych wpisow w tabeli ustawienie_tbl:
 * - ikom_typ_importu
 * - ikom_typ_linii
 * - ikom_wspolna_ikona
 * - ikom_robocza_admin
 * 
 * @TODO:
 * 1. Umozliwic operacje na calych liniach i kierunkach
 * - zmiana nazwy calej linii/kierunku
 * - ukrywanie/odkrywanie calej linii/kierunku 
 * 2. Dodac mozliwosc tworzenia i odtwarzania kopii bezpieczenstwa z poziomu modulu
 * 3. Optymalizacja importu pod katem wydajnosci i obciazen serwera
 * 4. Przerzucic domyslna lokalizacje dla googlemaps do bazy danych i wczytywac
 *    jednym mechanizmem do skryptow js
 * 5. Umożliwić import tras z logów urządzeń GPS - moze byc fajny feature
 * 6. Obsłuzyc prezentowanie internaucie rozkladu zaplanowanego
 **/

class komunikacjaActions extends sfActions
{
  public function preExecute()
  {
    $perm = ($this->getUser()->checkPermission('ikom','edit')==1)?true:false;
    if(!$perm || !in_array('ikom', ModulPeer::getEnabled()))
        $this->forward(sfConfig::get('sf_secure_module'),sfConfig::get('sf_secure_action'));
  }

  public function executeIndex(sfWebRequest $request)
  {
    $this->redirect('komunikacja/linie');
  }

  
  public function executeWiaty()
  {    
  }
  
  public function executeWiatasave(sfWebRequest $request)
  {     
    $wiata = KwiatyPeer::retrieveByPk($request->getParameter('wiata_id'));
    $wiata->setLokx($request->getParameter('lok_x'));
    $wiata->setLoky($request->getParameter('lok_y'));
    $wiata->setLokz($request->getParameter('lok_z'));
    $wiata->setKomunikat($request->getParameter('komunikat'));
    if($request->getParameter('icon')!='')
    	$wiata->setIkona($request->getParameter('icon'));
    $wiata->setStatus($request->getParameter('status'));
    $wiata->save();

    //nadpisanie statusu dla powiazanych tabliczek
        $c = new Criteria();
        $c->add(KtabliczkiPeer::NAZWAPRZYSTANKU, $wiata->getNazwawiaty(), Criteria::EQUAL);
        $przystanki_list = KtabliczkiPeer::doSelect($c);
        foreach($przystanki_list as $przystanek):
            $przystanek = KtabliczkiPeer::retrieveByPK($przystanek->getId());
            $przystanek->setStatus($request->getParameter('status'));
            $przystanek->save();
        endforeach;

    $this->getUser()->setFlash('notice', 'Poprawnie zapisano dane wiaty.');
    //$this->redirect('komunikacja/wiaty');
    $this->redirect('komunikacja/wiataedit?wiata_id='.$wiata->getId());
  } 
    
  public function executeWiataedit(sfWebRequest $request)
  { 	
    $id = $request->getParameter('wiata_id');
    $this->wiata = KwiatyPeer::retrieveByPk($id);

    $this->icon = $this->wiata->getIkona();
    $this->icon_dir = 'ikony/48x48/';
  }  
  
  public function executeWiataadd()
  {
    $this->icon = '';
    $this->icon_dir = 'ikony/48x48/';
  }
  
  public function executeWiatadelete(sfWebRequest $request)
  {
    if($request->getParameter('wiata_id')){
  	$wiata = KwiatyPeer::retrieveByPk($request->getParameter('wiata_id'));

        //usuniecie powiazanych przystankow
        $c = new Criteria();
        $c->add(KtabliczkiPeer::NAZWAPRZYSTANKU, $wiata->getNazwawiaty(), Criteria::EQUAL);
        $przystanki_list = KtabliczkiPeer::doSelect($c);
        foreach($przystanki_list as $przystanek):
            $przystanek_del = KtabliczkiPeer::retrieveByPK($przystanek->getId());
            $przystanek_del->delete();
        endforeach;

  	$wiata->delete();
        $this->getUser()->setFlash('notice', 'Poprawnie usunięto wiatę i powiązane przystanki.');
    }
    $this->redirect('komunikacja/wiaty');
  }
  
  public function executeWiataaddsave(sfWebRequest $request)
  {
  	$wiata = new Kwiaty();
  	$wiata->setNazwawiaty($request->getParameter('nazwawiaty'));
  	$wiata->setKomunikat($request->getParameter('komunikat'));
  	$wiata->setLokx($request->getParameter('lok_x'));
  	$wiata->setLoky($request->getParameter('lok_y'));
  	$wiata->setLokz($request->getParameter('lok_z'));  	
	if($request->getParameter('icon')!='')
            $wiata->setIkona($request->getParameter('icon'));
	$wiata->setStatus($request->getParameter('status'));
  	$wiata->save();

     $this->getUser()->setFlash('notice', 'Poprawnie dodano wiatę.');
     $this->redirect('komunikacja/wiataedit?wiata_id='.$wiata->getId());
  }
 
  public function executeImport(sfWebRequest $request)
  {
    //sprawdzamy z jakiego narzedzia importujemy dane
    $portal = sfConfig::get('portal');
    $typ_importu = UstawieniePeer::retrieveByPK('ikom_typ_importu',$portal->getId())->getTresc();

    //import z AGC Busman
    if($typ_importu == 'busman'){
        //$this->getUser()->setFlash('notice', 'Typ importu: AGC Busman');
  	$this->redirect('komunikacja/importbusman');
    }

    //import z MUNICOM++
    elseif($typ_importu == 'municom'){
        //$this->getUser()->setFlash('notice', 'Typ importu: Municom++ PZI Taran');
        $this->redirect('komunikacja/importmunicom');
    }
  }
  
  public function executeImportbusman(sfWebRequest $request)
  {
      //pobranie listy linii dla importu czesciowego
      $dir = sfConfig::get('sf_upload_dir').'/rozklady';

  	$list = scandir($dir);
  	$linie_list = array();
  	foreach($list as $item) {
  		if(is_dir($dir.'/'.$item) && strlen($item)==4){
  			$linie_list[] = $item;
  		}
  	}

  	$this->linie_list = $linie_list;

        $aktywne_wersje = KomunikacjaWersjePeer::doSelect(new Criteria());
        $options = array();
        foreach($aktywne_wersje as $wersja){
            $options[$wersja->getId()] = $wersja->getWersjaNazwa();
        }
        $this->aktywne_wersje_list = $options;

  }
  	
  public function executeImportbusmanpartBydgoszcz(sfWebRequest $request)
  { 
    //importuje do bazy dane z plikow html busmana [przykladowy import dla Bydgoszczy]
    $dir = sfConfig::get('sf_upload_dir').'/rozklady';

    //wybrane linie do importu
    $linie = $request->getParameter('linie');
    $wersja = $request->getParameter('wersja_id');

    $list = scandir($dir);

    foreach($list as $item) {
    //szukamy katalogow o 4-znakowej nazwie
	if(is_dir($dir.'/'.$item) && strlen($item)==4 && in_array($item, $linie)){
            $sublist = scandir($dir.'/'.$item);
						
            foreach($sublist as $subitem){
		//wyciagamy poszczegolne tabliczki z plikow w katalogu
		if(is_file($dir.'/'.$item.'/'.$subitem) && strlen($subitem)==13 && preg_match('/t[0-9][0-9][0-9].html/',$subitem)){
                    $subitem = str_replace('.html', '', $subitem);
                    
                    $tabliczka = addslashes(iconv("ISO-8859-2", "UTF-8", file_get_contents($dir.'/'.$item.'/'.$subitem.'.html')));
					
                    //wyciagniecie nazwy przystanku oraz kierunku ze znacznika w pliku HTML - patrz specyfikacja importu
                    $dane_temp = explode('</HTML><!--', $tabliczka);
								
                    //wyciagniecie nazwy przystanku
                    $nazwaprzystanku = explode('!!!', $dane_temp[1]);
					
                    //wyciagniecie nazwy kierunku - import dla bydgoszczy
                    $kierunek = explode('<B>KIERUNEK</B> / Direction /Richtung :', $dane_temp[1]);
                    $kierunek[1] = str_replace('-->', '', $kierunek[1]);
					
                    $tabliczki = new Ktabliczki();
                    $tabliczki->setLinia($item);
                    $tabliczki->setPrzystanek($subitem);
                    $tabliczki->setTabliczka($tabliczka);
                    $tabliczki->setNazwaprzystanku($nazwaprzystanku[0]);
                    $tabliczki->setKierunek($kierunek[1]);
                    $tabliczki->setWersjaId($wersja);
                    $tabliczki->save();
		}
            }
	}
    }
    $this->importWiat();
    
    return sfView::NONE;
  }

  public function executeImportbusmanpart(sfWebRequest $request) //import dla Radomia
  {
    //importuje do bazy dane z plikow html busmana [przykladowy import dla Bydgoszczy]
    $dir = sfConfig::get('sf_upload_dir').'/rozklady';

    //wybrane linie do importu
    $linie = $request->getParameter('linie');
    $wersja = $request->getParameter('wersja_id');

    $list = scandir($dir);

    foreach($list as $item) {
    //szukamy katalogow o 4-znakowej nazwie
	if(is_dir($dir.'/'.$item) && strlen($item)==4 && in_array($item, $linie)){
            $sublist = scandir($dir.'/'.$item);

            foreach($sublist as $subitem){
		//wyciagamy poszczegolne tabliczki z plikow w katalogu
		if(is_file($dir.'/'.$item.'/'.$subitem) && strlen($subitem)==12 && preg_match('/t[0-9][0-9][0-9].htm/',$subitem)){
                    $subitem = str_replace('.htm', '', $subitem);
                   
                    $tabliczka = addslashes(iconv("ISO-8859-2", "UTF-8", file_get_contents($dir.'/'.$item.'/'.$subitem.'.htm')));

                    //wyciagniecie nazwy przystanku oraz kierunku ze znacznika w pliku HTML - patrz specyfikacja importu
                    $dane_temp = explode('</HTML><!--', $tabliczka);

                    //wyciagniecie nazwy przystanku
                    $nazwaprzystanku = explode('!!!', $dane_temp[1]);

                    //wyciagniecie nazwy kierunku - import dla bydgoszczy
                    $kierunek = explode('- >', $dane_temp[1]);
                    $kierunek[1] = str_replace('-->', '', $kierunek[1]);

                    $tabliczki = new Ktabliczki();
                    $tabliczki->setLinia($item);
                    $tabliczki->setPrzystanek($subitem);
                    $tabliczki->setTabliczka($tabliczka);
                    $tabliczki->setNazwaprzystanku($nazwaprzystanku[0]);
                    $tabliczki->setKierunek($kierunek[1]);
                    $tabliczki->setWersjaId($wersja);

                    $portal = sfConfig::get('portal');
                        if(UstawieniePeer::retrieveByPK('ikom_typ_linii',$portal->getId())->getTresc()!=' ')
                            $tabliczki->setTyp(UstawieniePeer::retrieveByPK('ikom_typ_linii',$portal->getId())->getTresc());

                    $tabliczki->save();
		}
            }
	}
    }
    $this->importWiat();

    return sfView::NONE;
  }

  public function executeImportmunicom(sfWebRequest $request)
  {
    //pobranie listy linii dla importu czesciowego
      $dir = sfConfig::get('sf_upload_dir').'/rozklady-municom';

  	$list = scandir($dir);
  	$linie_list = array();
        $linie_nazwy_list = array();

  	foreach($list as $item) {
            
            if(is_file($dir.'/'.$item) && preg_match("/linia_/i", $item)){
      		$linie_list[] = $item;
                
                //wyciagamy numer linii 
                $temp_tresc = file_get_contents($dir.'/'.$item);
                //obciecie z lewej strony
                $temp1numer = explode('Trasa podstawowa linii&nbsp;', $temp_tresc);
                //obciecie z prawej strony
                $temp2numer = explode('&nbsp;w kierunku&nbsp;', $temp1numer[1]);

                //wyciagamy nazwe kierunku
                //obciecie z lewej strony
                $temp1kierunek = explode('&nbsp;w kierunku&nbsp;', $temp_tresc);
                //obciecie z prawej strony
                $temp2kierunek = explode('</b></font>', $temp1kierunek[1]);        
               
                
                $linie_nazwy_list[] = iconv('ISO-8859-2', 'UTF-8', $temp2numer[0]. '=> '.$temp2kierunek[0]);
               
            }           
  	}
        
    $this->linie_list = $linie_list;
    $this->linie_nazwy_list = $linie_nazwy_list;

    $aktywne_wersje = KomunikacjaWersjePeer::doSelect(new Criteria());
    $options = array();
    foreach($aktywne_wersje as $wersja){
        $options[$wersja->getId()] = $wersja->getWersjaNazwa();
    }
    $this->aktywne_wersje_list = $options;
  }

  public function executeImportmunicompart(sfWebRequest $request)
  {
      $dir = sfConfig::get('sf_upload_dir').'/rozklady-municom';

      //wybrane linie do importu
      $linie = $request->getParameter('linie');
      $wersja = $request->getParameter('wersja_id');


      //poszukiwanie tras podstawowych
      foreach($linie as $item) {
            if(is_file($dir.'/'.$item) && preg_match("/linia_/i", $item)){
      		$linie_list[] = $item;

                $temp_tresc = file_get_contents($dir.'/'.$item);

                //wyciagamy numer linii                
                //obciecie z lewej strony
                $temp1numer = explode('Trasa podstawowa linii&nbsp;', $temp_tresc);
                //obciecie z prawej strony
                $temp2numer = explode('&nbsp;w kierunku&nbsp;', $temp1numer[1]);

                //wyciagamy nazwe kierunku
                //obciecie z lewej strony
                $temp1kierunek = explode('&nbsp;w kierunku&nbsp;', $temp_tresc);
                //obciecie z prawej strony
                $temp2kierunek = explode('</b></font>', $temp1kierunek[1]);

                $numer_linii = $temp2numer[0];
                $kierunek_linii = trim(iconv('ISO-8859-2', 'UTF-8', $temp2kierunek[0]));
                
                //echo $numer_linii.'=>'.$kierunek_linii.'<br />';
                
                    //separacja tabliczek
                    //obciecie z lewej strony
                    $lista_tabliczek_temp = explode('<td  width="10%" align="center" bgcolor="#C0C0C0"><font face="Arial" size="-1" color="#000000">1</font></td>', $temp_tresc);

                    //obciecie z prawej strony
                    $lista_tabliczek_temp = explode('</table>', $lista_tabliczek_temp[1]);

                    $lista_tabliczek_temp[0] = iconv('ISO-8859-2', 'UTF-8', $lista_tabliczek_temp[0]);
                   
                    $adresy = $this->getLinks($lista_tabliczek_temp[0]);
                    //var_dump($adresy);

                    foreach($adresy as $key => $val){
                            
                            //echo $key.'=>'.$val.'<br />';
                            
                    		//mozna wyciagnac tabliczke w wersji do druku
                    		//$plik_tabliczki = str_replace(array('p_', '_m'), array('d_', ''), $key);
                    		
                    		//lub ta ktora wyswietla sie internaucie
                    		$plik_tabliczki = str_replace(array('_m'), array(''), $key);
                            
                            
                            $tabliczka_tresc = iconv('ISO-8859-2', 'UTF-8',file_get_contents($dir.'/'.$plik_tabliczki));
                            //echo $tabliczka_tresc;
                            
                        $tabliczka = new Ktabliczki();
                        $tabliczka->setLinia($numer_linii);
                        $tabliczka->setPrzystanek($key);
                        $tabliczka->setTabliczka($tabliczka_tresc);
                        $tabliczka->setNazwaprzystanku($val);
                        $tabliczka->setKierunek($kierunek_linii);
                        $tabliczka->setWersjaId($wersja);

                        $portal = sfConfig::get('portal');
                        if(UstawieniePeer::retrieveByPK('ikom_typ_linii',$portal->getId())->getTresc()!=' ')
                            $tabliczka->setTyp(UstawieniePeer::retrieveByPK('ikom_typ_linii',$portal->getId())->getTresc());

                        $tabliczka->save();
                    }
            }
      }
      //koniec poszukiwania tras podstawowych

      //poszukiwanie wariantow
      foreach($linie as $item) {
            if(is_file($dir.'/'.$item) && preg_match("/linia_/i", $item)){
      		$linie_list[] = $item;

                $temp_tresc = file_get_contents($dir.'/'.$item);
                //echo $dir.'/'.$item;

                //wyciagamy numer linii
                //obciecie z lewej strony
                $temp1numer = explode('Trasa podstawowa linii&nbsp;', $temp_tresc);
                //obciecie z prawej strony
                $temp2numer = explode('&nbsp;w kierunku&nbsp;', $temp1numer[1]);

                //wyciagamy nazwe kierunku
                //obciecie z lewej strony
                $temp1kierunek = explode('&nbsp;w kierunku&nbsp;', $temp_tresc);
                //obciecie z prawej strony
                $temp2kierunek = explode('</b></font>', $temp1kierunek[1]);

                $numer_linii = $temp2numer[0];
                $kierunek_linii = 'Pozostałe przystanki linii '.$numer_linii.' w kierunku ';
                $kierunek_linii .= trim(iconv('ISO-8859-2', 'UTF-8', $temp2kierunek[0]));
                
                //echo $numer_linii.'=>'.$kierunek_linii.'<br />';

                    //separacja tabliczek
                    //obciecie z lewej strony
                    //echo $temp_tresc;
                  $lista_tabliczek_temp = explode('Pozosta', $temp_tresc);

                    //obciecie z prawej strony
                  if(isset($lista_tabliczek_temp[1])){
                    $lista_tabliczek_temp = explode('<a href="#top_tabeli"><font color="#0000ff" size="-1" face="Arial">do g', $lista_tabliczek_temp[1]);

                    $lista_tabliczek_temp[0] = iconv('ISO-8859-2', 'UTF-8', $lista_tabliczek_temp[0]);

                    $lista_tabliczek_temp[0] = str_replace(array('<a href="#top_tabeli">'), array('top_tabeli'), $lista_tabliczek_temp[0]);
                    $adresy = $this->getLinks($lista_tabliczek_temp[0]);
                    
                    //echo $lista_tabliczek_temp[0];
                    //var_dump($adresy);

                    //ustalenie nazwy kierunku dla wariantu - ostatni przystanek wariantu
                    /*
                    $ile = sizeof($adresy);
                    foreach($adresy as $key => $val){
                        $kierunek_temp = $val;
                    }
                    $kierunek_linii .= '('.str_replace(array('"', '/'), array(' ',' '),$val).')';
                    $kierunek_linii .= '(wariant)';
                       */

                    foreach($adresy as $key => $val){

                            //echo $key.'=>'.$val.'<br />';

                    		//mozna wyciagnac tabliczke w wersji do druku
                    		//$plik_tabliczki = str_replace(array('p_', '_m'), array('d_', ''), $key);

                    		//lub ta ktora wyswietla sie internaucie
                    		$plik_tabliczki = str_replace(array('_m'), array(''), $key);


                            $tabliczka_tresc = iconv('ISO-8859-2', 'UTF-8',file_get_contents($dir.'/'.$plik_tabliczki));
                            //echo $tabliczka_tresc;

                        $tabliczka = new Ktabliczki();
                        $tabliczka->setLinia($numer_linii);
                        $tabliczka->setPrzystanek($key);
                        $tabliczka->setTabliczka($tabliczka_tresc);
                        $tabliczka->setNazwaprzystanku($val);
                        $tabliczka->setKierunek($kierunek_linii);
                        $tabliczka->setWersjaId($wersja);

                        $portal = sfConfig::get('portal');
                        if(UstawieniePeer::retrieveByPK('ikom_typ_linii',$portal->getId())->getTresc()!=' ')
                            $tabliczka->setTyp(UstawieniePeer::retrieveByPK('ikom_typ_linii',$portal->getId())->getTresc());

                        $tabliczka->save();
                    }
                  }
            }
      }
      //koniec wariantow

      //koniec zapisu do bazy

      //import nowych wiat
      $this->importWiat();
      return sfView::NONE;
  }

  protected function importWiat()
  {
    $wiaty = new KtabliczkiPeer();
    $c = new Criteria();
    $c->addAscendingOrderByColumn(KtabliczkiPeer::NAZWAPRZYSTANKU);
    $c->addGroupByColumn(KTabliczkiPeer::NAZWAPRZYSTANKU);
    $c->setDistinct();
    $wiaty_list = $wiaty->doSelect($c);

    $nowe = 0;
    $duplikaty = 0;


    //sprawdzamy czy wiata juz istnieje w bazie
    foreach($wiaty_list as $wiata_temp){
        $wiata_aktualna = new KwiatyPeer();
        $w = new Criteria();
        $w->add(KwiatyPeer::NAZWAWIATY, $wiata_temp->getNazwaPrzystanku(), Criteria::EQUAL);
        $istniejaca_wiata = $wiata_aktualna->doSelectOne($w);
        if($istniejaca_wiata) $duplikaty++;

        //jezeli wiata nie istnieje - dodajemy
        if(!$istniejaca_wiata){
            $wiata = new Kwiaty();
            $wiata->setNazwawiaty($wiata_temp->getNazwaprzystanku());
            $wiata->save();
            $nowe++;
        }

        
    }

    return $nowe;

  }

  public function getWersjaRobocza()
  {
    $portal = sfConfig::get('portal');
    $wersja_robocza = UstawieniePeer::retrieveByPK('ikom_robocza_admin',$portal->getId());

    return ($wersja_robocza->getTresc());
  }
 
  public function getLinie()
  {
    //pobieramy z bazy unikalne linie komunikacyjne dla aktywnej wersji

    $linie = new KtabliczkiPeer();
    $c = new Criteria();
    $c->add(KtabliczkiPeer::WERSJA_ID, $this->getWersjaRobocza());
    $c->addAscendingOrderByColumn(KtabliczkiPeer::LINIA);
    $c->addGroupByColumn(KtabliczkiPeer::LINIA);
    return ($linie->doSelect($c));
  }
  
  public function executeLinie()
  {
    $this->linie = $this->getLinie();
    
  }
  
  public function executeLinietree()
  {
    $this->linie = $this->getLinie();
  }
  
  public function executeLiniaadd()
  {
    $wiaty = new KwiatyPeer();
    $c = new Criteria();
    $c->addAscendingOrderByColumn(KwiatyPeer::NAZWAWIATY);
    $c->addGroupByColumn(KwiatyPeer::NAZWAWIATY);
    $this->wiaty_list = $wiaty->doSelect($c);

    $this->linie_list = $this->getLinie();
  }
  
  public function executeLiniaaddsave()
  {
  	
  }
  
  public function executeKierunki(sfWebRequest $request)
  {
  	//wyciąga z bazy listę kierunków dla danej linii
  	$kierunki = new KtabliczkiPeer();
  	$c = new Criteria();
  	$c->add(KtabliczkiPeer::LINIA, $request->getParameter('linia'));
        $c->add(KtabliczkiPeer::WERSJA_ID, $this->getWersjaRobocza());
  	$c->addGroupByColumn(KtabliczkiPeer::KIERUNEK);  	 
  	$this->kierunki_list =  $kierunki->doSelect($c);
  }
    
  public function executePrzystanki(sfWebRequest $request)
  { 
  	//wyciąga z bazy listę przystanków dla danej linii i kierunku 	
  	$temp = KtabliczkiPeer::retrieveByPK($request->getParameter('kierunek'));

       $przystanki = new KtabliczkiPeer();
  	$c = new Criteria();
  	$c->add(KtabliczkiPeer::LINIA, $request->getParameter('linia'));
  	$c->add(KtabliczkiPeer::KIERUNEK, $temp->getKierunek());
        $c->add(KtabliczkiPeer::WERSJA_ID, $this->getWersjaRobocza());
  	$c->addAscendingOrderByColumn(KtabliczkiPeer::KOLEJNOSC);
  	 	 
  	$this->przystanki_list =  $przystanki->doSelect($c);
  	
  	/* ------ dostepne przebiegi tras dla danej linii i kierunku ----- */
  	$this->trasy_list = $this->getDaneTrasy($request->getParameter('linia'), KtabliczkiPeer::retrieveByPK($request->getParameter('kierunek'))->getKierunek());

  	/* ------ kilka dodatkowych przydatnych zmiennych ----- */
  	$this->linia = $request->getParameter('linia');
  	$this->kierunek = $request->getParameter('kierunek');
  }
  
  public function executePrzystanekedit(sfWebRequest $request)
  {
  	/* ---- wyciaga z bazy dane pojedynczego przystanku i przekazuje do formularza edycji ---- */
  	$id = $request->getParameter('przystanek_id');  	
  	$przystanek = KtabliczkiPeer::retrieveByPk($id);

        /* ---- sprawdzenie domyslnej lokalizacji z tabeli wiat ---- */ 	
  	$wiata_temp = new KwiatyPeer();
  	$c = new Criteria();
  	$c->add(KwiatyPeer::NAZWAWIATY, $przystanek->getNazwaprzystanku());
  	$wiata = $wiata_temp->doSelectOne($c);
        
        //jezeli przystanek nie ma zdefiniowanej wlasnej lokalizacji
        if(!$przystanek->getLokX() && !$przystanek->getLokY() && !$przystanek->getLokZ()){
            if($wiata->getLokX() && $wiata->getLokY() && $wiata->getLokZ()){
                $przystanek->setLokX($wiata->getLokX());
                $przystanek->setLokY($wiata->getLokY());
                $przystanek->setLokZ($wiata->getLokZ());
                $komunikat = 'Lokalizacja domyślna z danych wiaty.';
            }
            else{
                $komunikat = 'Przystanek nie posiada lokalizacji.';
            }
        }
        else{
            $komunikat = 'Przystanek posiada własną lokalizację.';
        }
        
        $this->przystanek = $przystanek;
        $this->komunikat = $komunikat;

  	/* -------- ikony ----------- */
	$this->icon = $this->przystanek->getIkona();
	$this->icon_dir = 'ikony/48x48/';  	
  }
  
  public function executePrzystaneksave(sfWebRequest $request)
  {
  	//przechwycenie i zapis danych z formularza edycji przystanku
  	$przystanek = KtabliczkiPeer::retrieveByPk($request->getParameter('przystanek_id'));  	
  	$przystanek->setLokx($request->getParameter('lok_x'));
  	$przystanek->setLoky($request->getParameter('lok_y'));
  	$przystanek->setLokz($request->getParameter('lok_z'));
	$przystanek->setTabliczka($request->getParameter('tabliczka'));
	if($request->getParameter('icon')!='')
            $przystanek->setIkona($request->getParameter('icon'));
	$przystanek->setStatus($request->getParameter('status'));
        $przystanek->setKomunikat($request->getParameter('komunikat'));
	$przystanek->setTyp($request->getParameter('typ'));
  	$przystanek->save();

        //w przypadku zmiany typu linii w jednym przystanku -
        //zmieniamy typ dla wszystkich przystankow danej linii i kierunku
  	$dozmiany = new KtabliczkiPeer();
        $c = new Criteria();
        $c->add(KtabliczkiPeer::LINIA, $przystanek->getLinia(), Criteria::EQUAL);
        $c->add(KtabliczkiPeer::KIERUNEK, $przystanek->getKierunek(), Criteria::EQUAL);
        $c->add(KtabliczkiPeer::WERSJA_ID, $this->getWersjaRobocza());
        $zmiana_list = $dozmiany->doSelect($c);


        //sprawdzamy w konfiguracji czy ikona jest wspolna dla wszystkich przystankow w kierunku
        $portal_id = sfConfig::get('portal');
        $wspolna_ikona = UstawieniePeer::retrieveByPK('ikom_wspolna_ikona',$portal_id->getId());

        foreach($zmiana_list as $zmiana):
            $przystanek_temp = KtabliczkiPeer::retrieveByPk($zmiana->getId());
            //automatyczna zmiana typu linii dla pozostalych przystankow w kierunku
            $przystanek_temp->setTyp($request->getParameter('typ'));
            if($request->getParameter('icon')!='' && $wspolna_ikona->getTresc()=='tak'){
                //zmiana ikon dla reszty przystankow w kierunku
                $przystanek_temp->setIkona($request->getParameter('icon'));
            }
            $przystanek_temp->save();
        endforeach;

  }
  
  public function executePrzystanekadd(sfWebRequest $request)
  {  
  	$wiaty = new KwiatyPeer();
  	$c = new Criteria();
  	$c->addAscendingOrderByColumn(KwiatyPeer::NAZWAWIATY); 	 	
  	$c->addGroupByColumn(KwiatyPeer::NAZWAWIATY);  	 	
  	$this->wiaty_list = $wiaty->doSelect($c);  
  	$this->kierunek = $request->getParameter('kierunek');
  	$this->linia = $request->getParameter('linia');	
  }
  
  public function executePrzystanekaddsave(sfWebRequest $request)
  {
    if($request->getParameter('nazwaprzystanku')!='' && $request->getParameter('linia')!='' && $request->getParameter('kierunek')!=''){
  	$przystanek = new Ktabliczki();
  	
  	//znacznik - przystanek zostal dodany recznie  	
  	$przystanek->setPrzystanek('manual');
  	
  	$przystanek->setNazwaprzystanku($request->getParameter('nazwaprzystanku'));
  	$przystanek->setLinia($request->getParameter('linia'));
  	$temp = KtabliczkiPeer::retrieveByPK($request->getParameter('kierunek'));
        if($temp)
            $przystanek->setKierunek($temp->getKierunek());
        else
            $przystanek->setKierunek($request->getParameter('kierunek'));
  	$przystanek->setLokX(NULL);
  	$przystanek->setLokY(NULL);
  	$przystanek->setLokZ(NULL);
  	$przystanek->setIkona($request->getParameter('ikona'));
  	$przystanek->setTyp($request->getParameter('typ'));
  	$przystanek->setWersjaId($this->getWersjaRobocza());

        $przystanek->save();
        
        $this->komunikat = '<span class="notice">Przystanek został dodany</span>';
    }
    else{
        $komunikat = '<span class="error">Błąd:';
        if($request->getParameter('nazwaprzystanku')=='')
            $komunikat .= '&nbsp;wybierz wiatę';
        if($request->getParameter('linia')=='')
            $komunikat .= '&nbsp;podaj linię';
        if($request->getParameter('kierunek')=='')
            $komunikat .= '&nbsp;podaj kierunek';
        $komunikat .= '</span>';
        $this->komunikat = $komunikat;
    }
  }
  
  public function executePrzystanekdelete(sfWebRequest $request)
  {
    if($request->getParameter('przystanek_id')){
        $przystanek = KtabliczkiPeer::retrieveByPk($request->getParameter('przystanek_id'));
        $przystanek->delete();
   }
  }

  public function executeBatchactions(sfWebRequest $request)
  {
    //usuniecie calej wskazanej linii lub kierunku
    switch($request->getParameter('what')){
        case 'linia':
            $tabliczki = new KtabliczkiPeer();
            $c = new Criteria();
            $c->add(KtabliczkiPeer::LINIA, $request->getParameter('linia_id'));
            $c->add(KtabliczkiPeer::WERSJA_ID, $this->getWersjaRobocza());
            $tabliczki_list = $tabliczki->doSelect($c);
            foreach($tabliczki_list as $tabliczka):
                $del = KtabliczkiPeer::retrieveByPk($tabliczka->getId());
                $del->delete();
            endforeach;

            $this->komunikat = '<span class="notice">Linia zostałą usunięta</span>';
            break;

        case 'kierunek':
            $temp = KtabliczkiPeer::retrieveByPK($request->getParameter('kierunek_id'));


               $tabliczki = new KtabliczkiPeer();
            $c = new Criteria();
            $c->add(KtabliczkiPeer::LINIA, $request->getParameter('linia_id'));
            $c->add(KtabliczkiPeer::KIERUNEK, $temp->getKierunek());
            $c->add(KtabliczkiPeer::WERSJA_ID, $this->getWersjaRobocza());
            $tabliczki_list = $tabliczki->doSelect($c);
            foreach($tabliczki_list as $tabliczka):
                $del = KtabliczkiPeer::retrieveByPk($tabliczka->getId());
                $del->delete();
            endforeach;

            $this->komunikat = '<span class="notice">Kierunek został usunięty</span>';
            break;
        
        default: break;       
    }
  }

  public function executePrzystankikolejnosc(sfWebRequest $request)
  {
      $temp = KtabliczkiPeer::retrieveByPK($request->getParameter('kierunek'));


       $przystanki = new KtabliczkiPeer();
  	$c = new Criteria();
  	$c->add(KtabliczkiPeer::LINIA, $request->getParameter('linia'));
  	$c->add(KtabliczkiPeer::KIERUNEK, $temp->getKierunek());
        $c->add(KtabliczkiPeer::WERSJA_ID, $this->getWersjaRobocza());
        $c->addAscendingOrderByColumn(KtabliczkiPeer::KOLEJNOSC);
        $this->przystanki_list =  $przystanki->doSelect($c);

        $this->linia = $request->getParameter('linia');
        $this->kierunek = $request->getParameter('kierunek');
  }

  public function executeSort(sfWebRequest $request)
  {
      $order = $this->getRequestParameter('kolejnosc');
      $flag = KtabliczkiPeer::doSort($order);
      return $flag ? sfView::SUCCESS : sfView::ERROR;
  }

  public function executeTrasaedit(sfWebRequest $request)
  {
  	$this->linia = $request->getParameter('linia');
  	$this->kierunek = $request->getParameter('kierunek');
        $this->kierunek_obj = KtabliczkiPeer::retrieveByPk($this->kierunek);
  	$this->trasa_id = $request->getParameter('id');
  	  	  	
  	if($request->getParameter('id')!='new'){
  		//tryb edycji trasy - wyciagamy z bazy dane trasy o wybranym id
  		$this->trasa = KtrasyPeer::retrieveByPk($request->getParameter('id'));  		
  	}  

  	$this->points = $this->getPoints($request->getParameter('linia'), $this->kierunek_obj->getKierunek());
  	$this->pointsjson = $this->getPointsJson($request->getParameter('linia'), $this->kierunek_obj->getKierunek());
  
  	$this->points_separated_list = $this->getPointsseparated($request->getParameter('linia'), $this->kierunek_obj->getKierunek());
  }
  
  public function executeTrasapokazprzystanki(sfWebRequest $request)
  {
   //lista przystankow do pokazania podczas rysowania tras przebiegu linii
  	$temp = KtabliczkiPeer::retrieveByPK($request->getParameter('kierunek'));


       $przystanki = new KtabliczkiPeer();
  	$c = new Criteria(); 	
  	$c->add(KtabliczkiPeer::LINIA, $request->getParameter('linia'));
  	$c->add(KtabliczkiPeer::KIERUNEK, $temp->getKierunek());
        $c->add(KtabliczkiPeer::WERSJA_ID, $this->getWersjaRobocza());
  	$c->add(KtabliczkiPeer::STATUS, 0);
        $przystanki_list =  $przystanki->doSelect($c);

        //sprawdzenie czy przystanek posiada lokalizację, jeżeli nie - przeszukujemy dane wiat
        foreach($przystanki_list as $przystanek):
            if(!$przystanek->getLokX() && !$przystanek->getLokY() && !$przystanek->getLokZ()){
                $wiata_temp = new KwiatyPeer();
                $c = new Criteria();
                $c->add(KwiatyPeer::NAZWAWIATY, $przystanek->getNazwaprzystanku());
                $wiata = $wiata_temp->doSelectOne($c);

                if($wiata->getLokX() && $wiata->getLokY() && $wiata->getLokZ()){
                    $przystanek->setLokX($wiata->getLokX());
                    $przystanek->setLokY($wiata->getLokY());
                    $przystanek->setLokZ($wiata->getLokZ());
                }
            }
        endforeach;
        
        $this->przystanki_list = $przystanki_list;
  }
  
  public function executeTrasasave(sfWebRequest $request)
  {
  	//przechwycenie i zapis danych z formularza rysowania trasy
  	if($request->getParameter('trasa_id')){
  		//update juz istniejacej trasy
  		$trasa = KtrasyPeer::retrieveByPk($request->getParameter('trasa_id'));
  		$trasa->setLinia($request->getParameter('linia'));
  		$trasa->setKierunek(KtabliczkiPeer::retrieveByPK($request->getParameter('kierunek'))->getKierunek());
  		$trasa->setWezly($request->getParameter('polygon'));
  		if($request->getParameter('linia_nazwa')!=''){
  			$trasa->setLiniaNazwa($request->getParameter('linia_nazwa'));
  		}
  		else{
  			$trasa->setLiniaNazwa($request->getParameter('linia').'->'.$request->getParameter('kierunek'));
  		}
  		$trasa->setLineSize($request->getParameter('line_size'));
  		$trasa->setLineColor($request->getParameter('line_color'));
  		$trasa->setLineFillColor($request->getParameter('line_fill_color'));
  		$trasa->setLineOpacity($request->getParameter('line_opacity'));
  		$trasa->setStatus($request->getParameter('status'));
  		$trasa->save();
  	}
  	
  	else{
  		//zapis nowego wariantu przebiegu trasy
  		$trasa = new Ktrasy();
  		$trasa->setLinia($request->getParameter('linia'));
  		$trasa->setKierunek(KtabliczkiPeer::retrieveByPK($request->getParameter('kierunek'))->getKierunek());
                $trasa->setWezly($request->getParameter('polygon'));
  		$trasa->setLiniaNazwa($request->getParameter('linia_nazwa'));
  		$trasa->setLineSize($request->getParameter('line_size'));
  		$trasa->setLineColor($request->getParameter('line_color'));
  		$trasa->setLineFillColor($request->getParameter('line_fill_color'));
  		$trasa->setLineOpacity($request->getParameter('line_opacity'));
  		$trasa->setStatus($request->getParameter('status'));
  		$trasa->save();
  	}
  }
  
  public function executeTrasadelete(sfWebRequest $request)
  {
    //usuniecie trasy
    if($request->getParameter('id')){
            $trasa = KtrasyPeer::retrieveByPk($request->getParameter('id'));
            $trasa->delete();
  	}
  }

  public function getDaneTrasy($linia, $kierunek)
  {
  	//pobiera dane trasy dla danej linii i kierunku - do utworzenia listy przebiegow tras
  	$trasy = new KtrasyPeer();
  	$c = new Criteria();
  	$c->add(KtrasyPeer::LINIA, $linia);
  	$c->add(KtrasyPeer::KIERUNEK, $kierunek);  
  	return  $trasy->doSelect($c);
  }
  
  public function getPointsseparated($linia, $kierunek)
  {
  	$points = new KtabliczkiPeer();
  	$c = new Criteria();
  	$c->add(KtabliczkiPeer::STATUS, 0);  
  	$c->add(KtabliczkiPeer::LINIA, $linia);
  	$c->add(KtabliczkiPeer::KIERUNEK, $kierunek);
        $c->add(KtabliczkiPeer::WERSJA_ID, $this->getWersjaRobocza());
  	$c->addAscendingOrderByColumn(KtabliczkiPeer::KOLEJNOSC);
  	return $points->doSelect($c);
  }
  
  public function getPoints($linia, $kierunek)
  {
  	//wyciąga z bazy listę przystanków dla danej linii i kierunku 	
  	$przystanki = new KtabliczkiPeer();
  	$c = new Criteria();
  	$c->add(KtabliczkiPeer::STATUS, 0);  
  	$c->add(KtabliczkiPeer::LINIA, $linia);
  	$c->add(KtabliczkiPeer::KIERUNEK, $kierunek);
  	$c->add(KtabliczkiPeer::WERSJA_ID, $this->getWersjaRobocza());
        $c->addAscendingOrderByColumn(KtabliczkiPeer::KOLEJNOSC);
        $punkty_temp =  $przystanki->doSelect($c);
  	//return $przystanki->doSelect($c);

  	$waypoins = array();  	
  	foreach($punkty_temp as $punkt){
  		//indywidualna lokalizacja przystanku
  		if($punkt->getLokx() && $punkt->getLoky()){
  			$waypoints[] = ''.$punkt->getLokx().','.$punkt->getLoky().'';  			
  		}
  		//lokalizacja wiaty
  		else{
  			/* ---- sprawdzenie domyslnej lokalizacji z tabeli wiat ---- */ 
  			$wiata_temp = new KwiatyPeer();
  			$c = new Criteria();
  			$c->add(KwiatyPeer::NAZWAWIATY, $punkt->getNazwaprzystanku());
  			$wiata_list = $wiata_temp->doSelect($c);
  			foreach($wiata_list as $wiata){
  				if($wiata->getLokx() && $wiata->getLoky()){
  					$waypoints[] = ''.$wiata->getLokx().','.$wiata->getLoky().'';  					
  				}
  			}
  			
  		}
  	}
   	
  	return json_encode($waypoints);
  	//return implode(', ', $waypoints);
  	
   }
   
	public function getPointsJson($linia, $kierunek)
  	{
  	  //wyciąga z bazy listę przystanków dla danej linii i kierunku 	
  	  $przystanki = new KtabliczkiPeer();
  	  $c = new Criteria();
  	  $c->add(KtabliczkiPeer::STATUS, 0);  
  	  $c->add(KtabliczkiPeer::LINIA, $linia);
  	  $c->add(KtabliczkiPeer::KIERUNEK, $kierunek);
          $c->add(KtabliczkiPeer::WERSJA_ID, $this->getWersjaRobocza());
  	  $c->addAscendingOrderByColumn(KtabliczkiPeer::KOLEJNOSC);
  	  $punkty_temp =  $przystanki->doSelect($c);
    	//return $przystanki->doSelect($c);

  	  $waypoints2 = array();
  	  foreach($punkty_temp as $punkt){
  		//indywidualna lokalizacja przystanku
  		if($punkt->getLokx() && $punkt->getLoky()){  			
  			$waypoints2[] = '{"x": '.$punkt->getLokx().', "y": '.$punkt->getLoky().'}';
  		}
  		//lokalizacja wiaty
  		else{
  			/* ---- sprawdzenie domyslnej lokalizacji z tabeli wiat ---- */ 
  			$wiata_temp = new KwiatyPeer();
  			$c = new Criteria();
  			$c->add(KwiatyPeer::NAZWAWIATY, $punkt->getNazwaprzystanku());
  			$wiata_list = $wiata_temp->doSelect($c);
  			foreach($wiata_list as $wiata){
  				if($wiata->getLokx() && $wiata->getLoky()){  					
  					$waypoints2[] = '{"x": '.$wiata->getLokx().', "y": '.$wiata->getLoky().'}';
  				}
  			}
  			
  		}
  	}   	
  	
  	return implode(', ', $waypoints2);
   }
   
   public function executeKonfiguracja(sfWebRequest $request)
   {
     $portal = sfConfig::get('portal');
     $this->ikom_typ_importu = UstawieniePeer::retrieveByPK('ikom_typ_importu',$portal->getId());
     $this->ikom_typ_linii = UstawieniePeer::retrieveByPK('ikom_typ_linii',$portal->getId());
     $this->ikom_wspolna_ikona = UstawieniePeer::retrieveByPK('ikom_wspolna_ikona',$portal->getId());

   }

   public function executeKonfiguracjazapisz(sfWebRequest $request)
   {
       $portal_id = sfConfig::get('portal')->getId();

	//typ importu
	if($request->getParameter('ikom_typ_importu')){
            $ustawienie = UstawieniePeer::retrieveByPK('ikom_typ_importu',$portal_id);
            if(!$ustawienie){
                $conf = new Ustawienie();
		$conf->setNazwa('ikom_typ_importu');
		$conf->setTresc($request->getParameter('ikom_typ_importu'));
		$conf->setPortalId($portal_id);
		$conf->save();
            }
            else{
            	$ustawienie->setTresc($request->getParameter('ikom_typ_importu'));
            	$ustawienie->save();
            }
	}

        //domyslny typ linii
	if($request->getParameter('ikom_typ_linii')){
            $ustawienie = UstawieniePeer::retrieveByPK('ikom_typ_linii',$portal_id);
            if(!$ustawienie){
                $conf = new Ustawienie();
		$conf->setNazwa('ikom_typ_linii');
		$conf->setTresc($request->getParameter('ikom_typ_linii'));
		$conf->setPortalId($portal_id);
		$conf->save();
            }
            else{
            	$ustawienie->setTresc($request->getParameter('ikom_typ_linii'));
            	$ustawienie->save();
            }
        }
        //wspolna ikona
	if($request->getParameter('ikom_wspolna_ikona')){
            $ustawienie = UstawieniePeer::retrieveByPK('ikom_wspolna_ikona',$portal_id);
            if(!$ustawienie){
                $conf = new Ustawienie();
		$conf->setNazwa('ikom_wspolna_ikona');
		$conf->setTresc($request->getParameter('ikom_wspolna_ikona'));
		$conf->setPortalId($portal_id);
		$conf->save();
            }
            else{
            	$ustawienie->setTresc($request->getParameter('ikom_wspolna_ikona'));
            	$ustawienie->save();
            }
	}

        $this->redirect('komunikacja/konfiguracja');
        
   }

   public function executeBaza()
   {
       
   }
   
   public function executeBlank()
   {   	
   }
   
   public function executeRoutewezly(sfWebRequest $request)
   {
   	  $wezly = new KtabliczkiPeer();
  	  $c = new Criteria();
  	  $c->add(KtabliczkiPeer::STATUS, 0);  
  	  $c->add(KtabliczkiPeer::LINIA, $request->getParameter('linia'));
  	  $c->add(KtabliczkiPeer::KIERUNEK, $request->getParameter('kierunek'));
  	  $c->add(KtabliczkiPeer::WERSJA_ID, $this->getWersjaRobocza());

          $this->wezly_list =  $wezly->doSelect($c);
   }

   protected function getLinks($string)
   {
       //metoda zwraca tablice linkow znaleziona w ciagu znakow
        $ret = array();
        $dom = new domDocument();
        @$dom->loadHTML($string);
        $dom->preserveWhiteSpace = false;
        $links = $dom->getElementsByTagName('a');
        foreach ($links as $tag)
        {
            $ret[$tag->getAttribute('href')] = $this->charset_convert($tag->childNodes->item(0)->nodeValue);
        }
        return $ret;
    }

    protected function charset_convert($string)
    {
        //niektore rozklady maja kosmiczne kodowanie znakow - fix dla tychze
	return str_replace(
				array('Ä', 'Ã³', 'Å', 'Å', 'Ä', 'Ä', 'Å', 'Å', 'Åº', 'Å¼', 'Å»', 'Å', 'Å', 'Ã³', '', 'ą', 'â'),
				array('ę', 'ó', 'ł', 'ś', 'ć', 'ą', 'Ś', 'ń', 'ź', 'ż', 'Ż', 'Ł', 'Ś', 'Ó', '', 'Ć', ''),
				$string
	);
    }

    public function executeGeticon($request) {
        $request = $this->getRequest();
        $dir = $request->getParameter('icon_dir');
        $thelist = array();
        if ($handle = opendir($dir)) {
            while (false !== ($file = readdir($handle))){
                if ($file != "." && $file != ".."){
                    $filname_tbl = explode('.', $file);
                    if(sizeof($filname_tbl) > 1 ) {
                        if($filname_tbl[1] != 'png' && $filname_tbl[1] != 'jpg' && $filname_tbl[1] != 'gif' && $filname_tbl[1] != 'jpeg') continue;
                        $sub_dir = explode('images/', $dir);
                        $objec_dir = explode('images/ikony/48x48/', $dir);
                        $thelist[] = array('dir' => $sub_dir[1].'/', 'object_dir' => $objec_dir[1] ,'file' => $file );
                    }
                    else continue;

                }
                else continue;

            }
        closedir($handle);
        }

        $this->icon_list = $thelist;
    }
  
}

?>